pub struct Xoshiro256PlusPlus { /* private fields */ }Expand description
Xoshiro256++ generator state.
Examples
use vrd::xoshiro::Xoshiro256PlusPlus;
let rng = Xoshiro256PlusPlus::from_u64_seed(42);Implementations
Sourceimpl Xoshiro256PlusPlus
impl Xoshiro256PlusPlus
Sourcepub fn from_seed(seed: [u8; 32]) -> Self
pub fn from_seed(seed: [u8; 32]) -> Self
Builds an instance from a 32-byte seed, whitened via SplitMix64.
Examples
use vrd::xoshiro::Xoshiro256PlusPlus;
let seed = [0u8; 32];
let mut rng = Xoshiro256PlusPlus::from_seed(seed);
assert_ne!(rng.next_u64(), 0);Sourcepub fn from_u64_seed(seed: u64) -> Self
pub fn from_u64_seed(seed: u64) -> Self
Convenience constructor from a single u64 seed.
Examples
use vrd::xoshiro::Xoshiro256PlusPlus;
let mut rng = Xoshiro256PlusPlus::from_u64_seed(12345);
assert_ne!(rng.next_u64(), 0);Sourcepub fn next_u64(&mut self) -> u64
pub fn next_u64(&mut self) -> u64
Generates the next random u64.
Examples
use vrd::xoshiro::Xoshiro256PlusPlus;
let mut rng = Xoshiro256PlusPlus::from_u64_seed(42);
let n = rng.next_u64();Sourcepub fn next_u32(&mut self) -> u32
pub fn next_u32(&mut self) -> u32
Generates the next random u32 by taking the high 32 bits of the
next u64.
Examples
use vrd::xoshiro::Xoshiro256PlusPlus;
let mut rng = Xoshiro256PlusPlus::from_u64_seed(42);
let n = rng.next_u32();Sourcepub fn fill_bytes(&mut self, dest: &mut [u8])
pub fn fill_bytes(&mut self, dest: &mut [u8])
Fills dest with random bytes.
With the simd feature, large buffers go through a SIMD-batched
path that holds K independent Xoshiro256++ lanes in vector
registers (K = 2 on AArch64 NEON, K = 4 on x86_64 AVX2). Same
seed produces a different byte stream under simd vs.
scalar - see crate::xoshiro_simd for the contract.
Examples
use vrd::xoshiro::Xoshiro256PlusPlus;
let mut rng = Xoshiro256PlusPlus::from_u64_seed(42);
let mut buf = [0u8; 16];
rng.fill_bytes(&mut buf);Sourcepub fn jump(&mut self)
pub fn jump(&mut self)
Advances the state by 2^128 calls to Self::next_u64.
Examples
use vrd::xoshiro::Xoshiro256PlusPlus;
let mut rng = Xoshiro256PlusPlus::from_u64_seed(42);
rng.jump();Trait Implementations
Sourceimpl Clone for Xoshiro256PlusPlus
impl Clone for Xoshiro256PlusPlus
Sourcefn clone(&self) -> Xoshiro256PlusPlus
fn clone(&self) -> Xoshiro256PlusPlus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Xoshiro256PlusPlus
impl Debug for Xoshiro256PlusPlus
Sourceimpl<'de> Deserialize<'de> for Xoshiro256PlusPlus
impl<'de> Deserialize<'de> for Xoshiro256PlusPlus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for Xoshiro256PlusPlus
impl Hash for Xoshiro256PlusPlus
Sourceimpl Ord for Xoshiro256PlusPlus
impl Ord for Xoshiro256PlusPlus
Sourcefn cmp(&self, other: &Xoshiro256PlusPlus) -> Ordering
fn cmp(&self, other: &Xoshiro256PlusPlus) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for Xoshiro256PlusPlus
impl PartialEq for Xoshiro256PlusPlus
Sourceimpl PartialOrd for Xoshiro256PlusPlus
impl PartialOrd for Xoshiro256PlusPlus
Sourceimpl SeedableRng for Xoshiro256PlusPlus
impl SeedableRng for Xoshiro256PlusPlus
Sourcetype Seed = [u8; 32]
type Seed = [u8; 32]
Seed type, which is restricted to types mutably-dereferenceable as
u8
arrays (we recommend [u8; N] for some N). Read morefn seed_from_u64(state: u64) -> Self
fn seed_from_u64(state: u64) -> Self
Create a new PRNG using a
u64 seed. Read morefn from_rng<R>(rng: &mut R) -> Selfwhere
R: Rng + ?Sized,
fn from_rng<R>(rng: &mut R) -> Selfwhere
R: Rng + ?Sized,
Create a new PRNG seeded from an infallible
Rng. Read moreSourceimpl Serialize for Xoshiro256PlusPlus
impl Serialize for Xoshiro256PlusPlus
Sourceimpl TryRng for Xoshiro256PlusPlus
impl TryRng for Xoshiro256PlusPlus
Sourcetype Error = Infallible
type Error = Infallible
The type returned in the event of a RNG error. Read more
Sourcefn try_next_u32(&mut self) -> Result<u32, Self::Error>
fn try_next_u32(&mut self) -> Result<u32, Self::Error>
Return the next random
u32.Sourcefn try_next_u64(&mut self) -> Result<u64, Self::Error>
fn try_next_u64(&mut self) -> Result<u64, Self::Error>
Return the next random
u64.impl Copy for Xoshiro256PlusPlus
impl Eq for Xoshiro256PlusPlus
impl StructuralPartialEq for Xoshiro256PlusPlus